@@ -172,7 +172,7 @@ class ControllerWorker(object):
         if not db_health_monitor:
             LOG.warning('Failed to fetch %s %s from DB. Retrying for up to '
                         '60 seconds.', 'healthmonitor',
-                        db_health_monitor[constants.HEALTHMONITOR_ID])
+                        health_monitor[constants.HEALTHMONITOR_ID])
             raise db_exceptions.NoResultFound
 
         pool = db_health_monitor.pool
@@ -434,6 +434,14 @@ class ControllerWorker(object):
             flow_utils.get_update_load_balancer_flow,
             store=store)
 
+    @tenacity.retry(
+        retry=tenacity.retry_if_exception_type(db_exceptions.NoResultFound),
+        wait=tenacity.wait_incrementing(
+            CONF.haproxy_amphora.api_db_commit_retry_initial_delay,
+            CONF.haproxy_amphora.api_db_commit_retry_backoff,
+            CONF.haproxy_amphora.api_db_commit_retry_max),
+        stop=tenacity.stop_after_attempt(
+            CONF.haproxy_amphora.api_db_commit_retry_attempts))
     def create_member(self, member):
         """Creates a pool member.
 
@@ -441,8 +449,15 @@ class ControllerWorker(object):
         :returns: None
         :raises NoSuitablePool: Unable to find the node pool
         """
-        pool = self._pool_repo.get(db_apis.get_session(),
-                                   id=member[constants.POOL_ID])
+        db_member = self._member_repo.get(db_apis.get_session(),
+                                          id=member[constants.MEMBER_ID])
+        if not db_member:
+            LOG.warning('Failed to fetch %s %s from DB. Retrying for up to '
+                        '60 seconds.', 'l7member',
+                        member[constants.MEMBER_ID])
+            raise db_exceptions.NoResultFound
+
+        pool = db_member.pool
         load_balancer = pool.load_balancer
         provider_lb = provider_utils.db_loadbalancer_to_provider_loadbalancer(
             load_balancer).to_dict()
@@ -693,6 +708,14 @@ class ControllerWorker(object):
             flow_utils.get_update_pool_flow,
             store=store)
 
+    @tenacity.retry(
+        retry=tenacity.retry_if_exception_type(db_exceptions.NoResultFound),
+        wait=tenacity.wait_incrementing(
+            CONF.haproxy_amphora.api_db_commit_retry_initial_delay,
+            CONF.haproxy_amphora.api_db_commit_retry_backoff,
+            CONF.haproxy_amphora.api_db_commit_retry_max),
+        stop=tenacity.stop_after_attempt(
+            CONF.haproxy_amphora.api_db_commit_retry_attempts))
     def create_l7policy(self, l7policy):
         """Creates an L7 Policy.
 
@@ -700,8 +723,15 @@ class ControllerWorker(object):
         :returns: None
         :raises NoResultFound: Unable to find the object
         """
-        db_listener = self._listener_repo.get(
-            db_apis.get_session(), id=l7policy[constants.LISTENER_ID])
+        db_l7policy = self._l7policy_repo.get(
+            db_apis.get_session(), id=l7policy[constants.L7POLICY_ID])
+        if not db_l7policy:
+            LOG.warning('Failed to fetch %s %s from DB. Retrying for up to '
+                        '60 seconds.', 'l7policy',
+                        l7policy[constants.L7POLICY_ID])
+            raise db_exceptions.NoResultFound
+
+        db_listener = db_l7policy.listener
 
         listeners_dicts = (
             provider_utils.db_listeners_to_provider_dicts_list_of_dicts(
@@ -759,6 +789,14 @@ class ControllerWorker(object):
             flow_utils.get_update_l7policy_flow,
             store=store)
 
+    @tenacity.retry(
+        retry=tenacity.retry_if_exception_type(db_exceptions.NoResultFound),
+        wait=tenacity.wait_incrementing(
+            CONF.haproxy_amphora.api_db_commit_retry_initial_delay,
+            CONF.haproxy_amphora.api_db_commit_retry_backoff,
+            CONF.haproxy_amphora.api_db_commit_retry_max),
+        stop=tenacity.stop_after_attempt(
+            CONF.haproxy_amphora.api_db_commit_retry_attempts))
     def create_l7rule(self, l7rule):
         """Creates an L7 Rule.
 
@@ -766,8 +804,15 @@ class ControllerWorker(object):
         :returns: None
         :raises NoResultFound: Unable to find the object
         """
-        db_l7policy = self._l7policy_repo.get(db_apis.get_session(),
-                                              id=l7rule[constants.L7POLICY_ID])
+        db_l7rule = self._l7rule_repo.get(db_apis.get_session(),
+                                          id=l7rule[constants.L7RULE_ID])
+        if not db_l7rule:
+            LOG.warning('Failed to fetch %s %s from DB. Retrying for up to '
+                        '60 seconds.', 'l7rule',
+                        l7rule[constants.L7RULE_ID])
+            raise db_exceptions.NoResultFound
+
+        db_l7policy = db_l7rule.l7policy
 
         load_balancer = db_l7policy.listener.load_balancer
 
@@ -841,13 +886,14 @@ class ControllerWorker(object):
             flow_utils.get_update_l7rule_flow,
             store=store)
 
-    def failover_amphora(self, amphora_id):
+    def failover_amphora(self, amphora_id, reraise=False):
         """Perform failover operations for an amphora.
 
         Note: This expects the load balancer to already be in
         provisioning_status=PENDING_UPDATE state.
 
         :param amphora_id: ID for amphora to failover
+        :param reraise: If enabled reraise any caught exception
         :returns: None
         :raises octavia.common.exceptions.NotFound: The referenced amphora was
                                                     not found
@@ -922,7 +968,7 @@ class ControllerWorker(object):
                              constants.LOADBALANCER_ID: lb_id,
                              constants.VIP: vip_dict}
 
-            self.services_controller.run_poster(
+            self.run_flow(
                 flow_utils.get_failover_amphora_flow,
                 amphora.to_dict(), lb_amp_count,
                 store=stored_params, wait=True)
@@ -935,7 +981,7 @@ class ControllerWorker(object):
                       "role": amphora.role})
 
         except Exception as e:
-            with excutils.save_and_reraise_exception(reraise=False):
+            with excutils.save_and_reraise_exception(reraise=reraise):
                 LOG.exception("Amphora %s failover exception: %s",
                               amphora_id, str(e))
                 self._amphora_repo.update(db_apis.get_session(),
@@ -1074,7 +1120,7 @@ class ControllerWorker(object):
             else:
                 stored_params[constants.AVAILABILITY_ZONE] = {}
 
-            self.services_controller.run_poster(
+            self.run_flow(
                 flow_utils.get_failover_LB_flow, amps, provider_lb_dict,
                 store=stored_params, wait=True)
 
